/****************************************************************************
** QgsCopyrightLabelPluginGui meta object code from reading C++ file 'plugingui.h'
**
** Created: Fri Nov 4 14:26:23 2005
**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#undef QT_NO_COMPAT
#include "plugingui.h"
#include <qmetaobject.h>
#include <qapplication.h>

#include <private/qucomextra_p.h>
#if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
#error "This file was generated using the moc from 3.3.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

const char *QgsCopyrightLabelPluginGui::className() const
{
    return "QgsCopyrightLabelPluginGui";
}

QMetaObject *QgsCopyrightLabelPluginGui::metaObj = 0;
static QMetaObjectCleanUp cleanUp_QgsCopyrightLabelPluginGui( "QgsCopyrightLabelPluginGui", &QgsCopyrightLabelPluginGui::staticMetaObject );

#ifndef QT_NO_TRANSLATION
QString QgsCopyrightLabelPluginGui::tr( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsCopyrightLabelPluginGui", s, c, QApplication::DefaultCodec );
    else
	return QString::fromLatin1( s );
}
#ifndef QT_NO_TRANSLATION_UTF8
QString QgsCopyrightLabelPluginGui::trUtf8( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsCopyrightLabelPluginGui", s, c, QApplication::UnicodeUTF8 );
    else
	return QString::fromUtf8( s );
}
#endif // QT_NO_TRANSLATION_UTF8

#endif // QT_NO_TRANSLATION

QMetaObject* QgsCopyrightLabelPluginGui::staticMetaObject()
{
    if ( metaObj )
	return metaObj;
    QMetaObject* parentObject = QgsCopyrightLabelPluginGuiBase::staticMetaObject();
    static const QUParameter param_slot_0[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_0 = {"setEnabled", 1, param_slot_0 };
    static const QMetaData slot_tbl[] = {
	{ "setEnabled(bool)", &slot_0, QMetaData::Public }
    };
    static const QUParameter param_signal_0[] = {
	{ 0, &static_QUType_varptr, "\x05", QUParameter::In }
    };
    static const QUMethod signal_0 = {"changeFont", 1, param_signal_0 };
    static const QUParameter param_signal_1[] = {
	{ 0, &static_QUType_QString, 0, QUParameter::In }
    };
    static const QUMethod signal_1 = {"changeLabel", 1, param_signal_1 };
    static const QUParameter param_signal_2[] = {
	{ 0, &static_QUType_varptr, "\x0a", QUParameter::In }
    };
    static const QUMethod signal_2 = {"changeColor", 1, param_signal_2 };
    static const QUParameter param_signal_3[] = {
	{ 0, &static_QUType_QString, 0, QUParameter::In }
    };
    static const QUMethod signal_3 = {"changePlacement", 1, param_signal_3 };
    static const QUParameter param_signal_4[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod signal_4 = {"enableCopyrightLabel", 1, param_signal_4 };
    static const QMetaData signal_tbl[] = {
	{ "changeFont(QFont)", &signal_0, QMetaData::Private },
	{ "changeLabel(QString)", &signal_1, QMetaData::Private },
	{ "changeColor(QColor)", &signal_2, QMetaData::Private },
	{ "changePlacement(QString)", &signal_3, QMetaData::Private },
	{ "enableCopyrightLabel(bool)", &signal_4, QMetaData::Private }
    };
    metaObj = QMetaObject::new_metaobject(
	"QgsCopyrightLabelPluginGui", parentObject,
	slot_tbl, 1,
	signal_tbl, 5,
#ifndef QT_NO_PROPERTIES
	0, 0,
	0, 0,
#endif // QT_NO_PROPERTIES
	0, 0 );
    cleanUp_QgsCopyrightLabelPluginGui.setMetaObject( metaObj );
    return metaObj;
}

void* QgsCopyrightLabelPluginGui::qt_cast( const char* clname )
{
    if ( !qstrcmp( clname, "QgsCopyrightLabelPluginGui" ) )
	return this;
    return QgsCopyrightLabelPluginGuiBase::qt_cast( clname );
}

#include <qobjectdefs.h>
#include <qsignalslotimp.h>

// SIGNAL changeFont
void QgsCopyrightLabelPluginGui::changeFont( QFont t0 )
{
    if ( signalsBlocked() )
	return;
    QConnectionList *clist = receivers( staticMetaObject()->signalOffset() + 0 );
    if ( !clist )
	return;
    QUObject o[2];
    static_QUType_varptr.set(o+1,&t0);
    activate_signal( clist, o );
}

// SIGNAL changeLabel
void QgsCopyrightLabelPluginGui::changeLabel( QString t0 )
{
    activate_signal( staticMetaObject()->signalOffset() + 1, t0 );
}

// SIGNAL changeColor
void QgsCopyrightLabelPluginGui::changeColor( QColor t0 )
{
    if ( signalsBlocked() )
	return;
    QConnectionList *clist = receivers( staticMetaObject()->signalOffset() + 2 );
    if ( !clist )
	return;
    QUObject o[2];
    static_QUType_varptr.set(o+1,&t0);
    activate_signal( clist, o );
}

// SIGNAL changePlacement
void QgsCopyrightLabelPluginGui::changePlacement( QString t0 )
{
    activate_signal( staticMetaObject()->signalOffset() + 3, t0 );
}

// SIGNAL enableCopyrightLabel
void QgsCopyrightLabelPluginGui::enableCopyrightLabel( bool t0 )
{
    activate_signal_bool( staticMetaObject()->signalOffset() + 4, t0 );
}

bool QgsCopyrightLabelPluginGui::qt_invoke( int _id, QUObject* _o )
{
    switch ( _id - staticMetaObject()->slotOffset() ) {
    case 0: setEnabled((bool)static_QUType_bool.get(_o+1)); break;
    default:
	return QgsCopyrightLabelPluginGuiBase::qt_invoke( _id, _o );
    }
    return TRUE;
}

bool QgsCopyrightLabelPluginGui::qt_emit( int _id, QUObject* _o )
{
    switch ( _id - staticMetaObject()->signalOffset() ) {
    case 0: changeFont((QFont)(*((QFont*)static_QUType_ptr.get(_o+1)))); break;
    case 1: changeLabel((QString)static_QUType_QString.get(_o+1)); break;
    case 2: changeColor((QColor)(*((QColor*)static_QUType_ptr.get(_o+1)))); break;
    case 3: changePlacement((QString)static_QUType_QString.get(_o+1)); break;
    case 4: enableCopyrightLabel((bool)static_QUType_bool.get(_o+1)); break;
    default:
	return QgsCopyrightLabelPluginGuiBase::qt_emit(_id,_o);
    }
    return TRUE;
}
#ifndef QT_NO_PROPERTIES

bool QgsCopyrightLabelPluginGui::qt_property( int id, int f, QVariant* v)
{
    return QgsCopyrightLabelPluginGuiBase::qt_property( id, f, v);
}

bool QgsCopyrightLabelPluginGui::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
#endif // QT_NO_PROPERTIES
